package cache
import "github.com/google/cadvisor/cache"
Index ¶
Types ¶
type Cache ¶
type Cache interface {
// Add a ContainerStats for the specified container.
AddStats(ref info.ContainerReference, stats *info.ContainerStats) error
// Remove all cached information for the specified container.
RemoveContainer(containerName string) error
// Read most recent stats. numStats indicates max number of stats
// returned. The returned stats must be consecutive observed stats. If
// numStats < 0, then return all stats stored in the storage. The
// returned stats should be sorted in time increasing order, i.e. Most
// recent stats should be the last.
RecentStats(containerName string, numStats int) ([]*info.ContainerStats, error)
// Close will clear the state of the storage driver. The elements
// stored in the underlying storage may or may not be deleted depending
// on the implementation of the storage driver.
Close() error
}
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| cache/memory |
- Version
- v0.55.1 (latest)
- Published
- Dec 19, 2025
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 4 months ago –
Tools for package owners.