package devicemapper

import "github.com/google/cadvisor/fs/devicemapper"

Index

Functions

func DockerDMDevice

func DockerDMDevice(driverStatus map[string]string, dmsetup dm.DmsetupClient) (string, uint, uint, uint, error)

DockerDMDevice returns information about the devicemapper device and "partition" if docker is using devicemapper for its storage driver.

func GetDMStats

func GetDMStats(poolName string, dataBlkSize uint) (uint64, uint64, uint64, error)

GetDMStats returns devicemapper thin provisioning stats.

func NewPlugin

func NewPlugin() fs.FsPlugin

NewPlugin creates a new DeviceMapper filesystem plugin.

func ParseDMTable

func ParseDMTable(dmTable string) (uint, uint, uint, error)

parseDMTable parses a single line of `dmsetup table` output and returns the major device, minor device, block size, and an error.

Source Files

plugin.go stats.go

Directories

PathSynopsis
fs/devicemapper/install
Version
v0.55.1 (latest)
Published
Dec 19, 2025
Platform
linux/amd64
Imports
8 packages
Last checked
4 months ago

Tools for package owners.