package framework
import "github.com/google/cadvisor/integration/framework"
Index ¶
- Constants
- func RetryForDuration(retryFunc func() error, dur time.Duration) error
- type CadvisorActions
- type CrioActions
- type CrioRunArgs
- type DockerActions
- type DockerRunArgs
- type Framework
- type HostnameInfo
- type ShellActions
Constants ¶
const ( Aufs string = "aufs" Overlay string = "overlay" Overlay2 string = "overlay2" DeviceMapper string = "devicemapper" Unknown string = "" )
Functions ¶
func RetryForDuration ¶
Runs retryFunc until no error is returned. After dur time the last error is returned. Note that the function does not timeout the execution of retryFunc when the limit is reached.
Types ¶
type CadvisorActions ¶
type CadvisorActions interface {
// Returns a cAdvisor client to the machine being tested.
Client() *client.Client
ClientV2() *v2.Client
}
type CrioActions ¶
type CrioActions interface {
// Run the no-op pause CRI-O container and return its ID.
RunPause() string
// Run the specified command in a CRI-O busybox container and return its ID.
RunBusybox(cmd ...string) string
// Runs a CRI-O container in the background. Uses the specified CrioRunArgs and command.
// Returns the ID of the new container.
Run(args CrioRunArgs, cmd ...string) string
}
CrioActions provides methods for managing CRI-O containers in tests. CRI-O containers run inside pod sandboxes, so each container requires a pod to be created first.
type CrioRunArgs ¶
type CrioRunArgs struct {
// Image to use.
Image string
// Container name (optional, auto-generated if empty).
Name string
}
CrioRunArgs contains arguments for running a CRI-O container.
type DockerActions ¶
type DockerActions interface {
// Run the no-op pause Docker container and return its ID.
RunPause() string
// Run the specified command in a Docker busybox container and return its ID.
RunBusybox(cmd ...string) string
// Runs a Docker container in the background. Uses the specified DockerRunArgs and command.
// Returns the ID of the new container.
//
// e.g.:
// Run(DockerRunArgs{Image: "busybox"}, "ping", "www.google.com")
// -> docker run busybox ping www.google.com
Run(args DockerRunArgs, cmd ...string) string
RunStress(args DockerRunArgs, cmd ...string) string
Version() []string
StorageDriver() string
}
type DockerRunArgs ¶
type DockerRunArgs struct {
// Image to use.
Image string
// Arguments to the Docker CLI.
Args []string
InnerArgs []string
}
type Framework ¶
type Framework interface {
// Clean the framework state.
Cleanup()
// The testing.T used by the framework and the current test.
T() *testing.T
// Returns the hostname being tested.
Hostname() HostnameInfo
// Returns the Docker actions for the test framework.
Docker() DockerActions
// Returns the CRI-O actions for the test framework.
Crio() CrioActions
// Returns the shell actions for the test framework.
Shell() ShellActions
// Returns the cAdvisor actions for the test framework.
Cadvisor() CadvisorActions
}
Integration test framework.
func New ¶
Instantiates a Framework. Cleanup *must* be called. Class is thread-compatible. All framework actions report fatal errors on the t specified at creation time.
Typical use:
func TestFoo(t *testing.T) {
fm := framework.New(t)
defer fm.Cleanup()
... actual test ...
}
type HostnameInfo ¶
func (HostnameInfo) FullHostname ¶
func (h HostnameInfo) FullHostname() string
Returns: http://<host>:<port>/
type ShellActions ¶
type ShellActions interface {
// Runs a specified command and arguments. Returns the stdout and stderr.
Run(cmd string, args ...string) (string, string)
RunStress(cmd string, args ...string) (string, string)
}
Source Files ¶
- Version
- v0.55.1 (latest)
- Published
- Dec 19, 2025
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 4 months ago –
Tools for package owners.