package cloudinfo
import "github.com/google/cadvisor/utils/cloudinfo"
Index ¶
- func RegisterCloudProvider(name info.CloudProvider, provider CloudProvider)
- type CloudInfo
- type CloudProvider
Functions ¶
func RegisterCloudProvider ¶
func RegisterCloudProvider(name info.CloudProvider, provider CloudProvider)
RegisterCloudProvider registers the given cloud provider
Types ¶
type CloudInfo ¶
type CloudInfo interface {
GetCloudProvider() info.CloudProvider
GetInstanceType() info.InstanceType
GetInstanceID() info.InstanceID
}
func NewRealCloudInfo ¶
func NewRealCloudInfo() CloudInfo
type CloudProvider ¶
type CloudProvider interface {
// IsActiveProvider determines whether this is the cloud provider operating
// this instance.
IsActiveProvider() bool
// GetInstanceType gets the type of instance this process is running on.
// The behavior is undefined if this is not the active provider.
GetInstanceType() info.InstanceType
// GetInstanceType gets the ID of the instance this process is running on.
// The behavior is undefined if this is not the active provider.
GetInstanceID() info.InstanceID
}
CloudProvider is an abstraction for providing cloud-specific information.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| utils/cloudinfo/aws | |
| utils/cloudinfo/azure | |
| utils/cloudinfo/gce |
- Version
- v0.55.1 (latest)
- Published
- Dec 19, 2025
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 4 months ago –
Tools for package owners.