package cpuload
import "github.com/google/cadvisor/utils/cpuload"
Index ¶
Types ¶
type CpuLoadReader ¶
type CpuLoadReader interface {
// Start the reader.
Start() error
// Stop the reader and clean up internal state.
Stop()
// Retrieve Cpu load for a given group.
// name is the full hierarchical name of the container.
// Path is an absolute filesystem path for a container under CPU cgroup hierarchy.
GetCpuLoad(name string, path string) (info.LoadStats, error)
}
func New ¶
func New() (CpuLoadReader, error)
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| utils/cpuload/netlink | |
| utils/cpuload/netlink/example |
- Version
- v0.55.1 (latest)
- Published
- Dec 19, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 4 months ago –
Tools for package owners.