package oomparser
import "github.com/google/cadvisor/utils/oomparser"
Index ¶
Types ¶
type OomInstance ¶
type OomInstance struct {
// process id of the killed process
Pid int
// the name of the killed process
ProcessName string
// the time that the process was reported to be killed,
// accurate to the minute
TimeOfDeath time.Time
// the absolute name of the container that OOMed
ContainerName string
// the absolute name of the container that was killed
// due to the OOM.
VictimContainerName string
// the constraint that triggered the OOM. One of CONSTRAINT_NONE,
// CONSTRAINT_CPUSET, CONSTRAINT_MEMORY_POLICY, CONSTRAINT_MEMCG
Constraint string
}
struct that contains information related to an OOM kill instance
type OomParser ¶
type OomParser struct {
// contains filtered or unexported fields
}
OomParser wraps a kmsgparser in order to extract OOM events from the individual kernel ring buffer messages.
func New ¶
initializes an OomParser object. Returns an OomParser object and an error.
func (*OomParser) StreamOoms ¶
func (p *OomParser) StreamOoms(outStream chan<- *OomInstance)
StreamOoms writes to a provided a stream of OomInstance objects representing OOM events that are found in the logs. It will block and should be called from a goroutine.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| utils/oomparser/oomexample |
- Version
- v0.55.1 (latest)
- Published
- Dec 19, 2025
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 4 months ago –
Tools for package owners.