package btrfs
import "github.com/google/cadvisor/fs/btrfs"
Index ¶
Functions ¶
func GetBtrfsMajorMinorIds ¶
GetBtrfsMajorMinorIds gets the major and minor device IDs for a btrfs mount point. This is a workaround for wrong btrfs Major and Minor Ids reported in /proc/self/mountinfo. Instead of using values from /proc/self/mountinfo we use stat to get Ids from btrfs mount point.
func NewPlugin ¶
NewPlugin creates a new Btrfs filesystem plugin.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| fs/btrfs/install |
- Version
- v0.55.1 (latest)
- Published
- Dec 19, 2025
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 4 months ago –
Tools for package owners.